@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: imp/compose.php,v 2.800.2.122 2009/01/30 00:07:13 jan Exp $
+ * $Horde: imp/compose.php,v 2.800.2.129 2009-11-22 17:10:10 jan Exp $
  *
  * Copyright 1999-2009 The Horde Project (http://www.horde.org/)
  *
@@ -249,6 +249,7 @@ if ($_SESSION['imp']['file_upload']) {
 }
 
 /* Run through the action handlers. */
+$reply_type = null;
 $title = _("New Message");
 switch ($actionID) {
 case 'recompose':
@@ -309,6 +310,9 @@ case 'draft':
             $identity->setDefault($result['identity']);
             $sent_mail_folder = $identity->getValue('sent_mail_folder');
         }
+        if (isset($result['header']['references'])) {
+            $reply_type = 'reply';
+        }
     }
     $get_sig = false;
     break;
@@ -435,7 +439,7 @@ case 'send_message':
         'save_attachments' => Util::getFormData('save_attachments_select'),
         'reply_type' => Util::getFormData('reply_type'),
         'reply_index' => (empty($reply_index) ? null : $reply_index . IMP_IDX_SEP . $thismailbox),
-        'encrypt' => Util::getFormData('encrypt_options'),
+        'encrypt' => $prefs->isLocked('default_encrypt') ? $prefs->getValue('default_encrypt') : Util::getFormData('encrypt_options'),
         'priority' => Util::getFormData('x_priority'),
         'readreceipt' => Util::getFormData('request_read_receipt')
     );
@@ -716,9 +720,10 @@ if ($pgp_passphrase_dialog || $pgp_symmetric_passphrase_dialog) {
 
 /* If PGP encryption is set by default, and we have a recipient list on first
  * load, make sure we have public keys for all recipients. */
-$encrypt_options = Util::getFormData('encrypt_options');
-$use_pgp = $prefs->getValue('use_pgp');
-if ($use_pgp) {
+$encrypt_options = $prefs->isLocked('default_encrypt')
+      ? $prefs->getValue('default_encrypt')
+      : Util::getFormData('encrypt_options');
+if ($prefs->getValue('use_pgp') && !$prefs->isLocked('default_encrypt')) {
     $default_encrypt = $prefs->getValue('default_encrypt');
     if (!$reloaded &&
         in_array($default_encrypt, array(IMP_PGP_ENCRYPT, IMP_PGP_SIGNENC))) {
@@ -869,7 +874,7 @@ if ($redirect) {
 
     echo $t->fetch(IMP_TEMPLATES . '/compose/redirect.html');
 } else {
-    if (!($reply_type = Util::getFormData('reply_type'))) {
+    if (!($reply_type = Util::getFormData('reply_type', $reply_type))) {
         switch ($actionID) {
         case 'reply':
         case 'reply_all':
@@ -924,7 +929,6 @@ if ($redirect) {
     $t->set('hidden', $hidden);
 
     $t->set('title', htmlspecialchars($title));
-    $t->set('status', IMP::status());
     $t->set('send_msg_ak', Horde::getAccessKeyAndTitle(_("_Send Message")));
     if ($conf['user']['allow_folders']) {
         $t->set('save_draft_ak', Horde::getAccessKeyAndTitle(_("Save _Draft")));
@@ -1099,8 +1103,7 @@ if ($redirect) {
     }
     if ($_SESSION['imp']['file_upload']) {
         $compose_options[] = array(
-            'url' => Horde::link('#attachments', '', 'widget', null,
-                                 'Field.focus(\'upload_1\');return false;'),
+            'url' => Horde::link('#attachments', '', 'widget'),
             'img' => Horde::img('manage_attachments.png'),
             'label' => $show_text ? _("Attachments") : '');
     }
@@ -1116,6 +1119,14 @@ if ($redirect) {
         }
         if (!empty($conf['user']['select_sentmail_folder']) &&
             !$prefs->isLocked('sent_mail_folder')) {
+            /* Check to make sure the sent-mail folder is created - it needs
+             * to exist to show up in drop-down list. */
+            require_once IMP_BASE . '/lib/Folder.php';
+            $imp_folder = &IMP_Folder::singleton();
+            if (!$imp_folder->exists($sent_mail_folder)) {
+                $imp_folder->create($sent_mail_folder, true);
+            }
+
             $t->set('ssm_tabindex', ++$tabindex);
             $t->set('ssm_folders', IMP::flistSelect('', false, array('INBOX'), $sent_mail_folder));
         } else {
@@ -1147,9 +1158,13 @@ if ($redirect) {
 
     $t->set('use_encrypt', ($prefs->getValue('use_pgp') || $prefs->getValue('use_smime')));
     if ($t->get('use_encrypt')) {
-        $t->set('encrypt_label', Horde::label('encrypt_options', _("Encr_yption Options")));
-        $t->set('encrypt_options', IMP::encryptList($encrypt_options));
-        $t->set('help-encrypt', Help::link('imp', 'compose-options-encrypt'));
+        if ($prefs->isLocked('default_encrypt')) {
+            $t->set('use_encrypt', false);
+        } else {
+            $t->set('encrypt_label', Horde::label('encrypt_options', _("Encr_yption Options")));
+            $t->set('encrypt_options', IMP::encryptList($encrypt_options));
+            $t->set('help-encrypt', Help::link('imp', 'compose-options-encrypt'));
+        }
         $t->set('pgp_options', ($prefs->getValue('use_pgp') && $prefs->getValue('pgp_public_key')));
         if ($t->get('pgp_options')) {
             $t->set('pgp_attach_pubkey', Util::getFormData('pgp_attach_pubkey', $prefs->getValue('pgp_attach_pubkey')));
@@ -1232,6 +1247,7 @@ if ($redirect) {
         }
     }
 
+    $t->set('status', IMP::status());
     echo $t->fetch(IMP_TEMPLATES . '/compose/compose.html');
 }
 
